Appellate Division, Third Judicial Department: Feb 11, 2016

Appellate Division, Third Judicial Department 11 February 2016, Thursday |
Decisions are subject to revision before publication in the Appellate Division Reports. Memorandum Decisions 105534/105559 People v Kerrick 105548 People v Wlasiuk 106223 People v Blair 106267 People v Davis 106350 People v Smith 106351 People v Ryder 106496 People v Martin 106508 People v Turner 106517 People v Shipps 106608 People v Griffith 106925 People v Forget 106929 People v Cota 107054 People v Buck 107061 People v DeAngelo 107062 People v McKenzie 107090 People v Crispell 107231 People v Brasmeister 107653 People v Riddick 519121 People v Rowe 519745 Matter of Nanterne v Ahdoot 519985 Matter of Tricarico v Town of Islip 520174 Matter of Eray Inc. (Commr. of Labor) 520549/520958 Miazga v Assaf 520617 Matter of Boyd v Prack 520729 Matter of Chirico (Commr. of Labor) 520828 Matter of Zaharuk (Commr. of Labor) 521120 Matter of Zobel v Chemung County 521295 Matter of Mullins v New York State Board of Parole 521372 Matter of Ripp v New York State and Local Police and Fire Retirement System 521441 Matter of Reddien v Joseph Davis Inc. Attorney Disciplinary/Admission Decisions D-3-16 Matter of Attorneys in Violation of Judiciary Law § 468-a [Shiffman] D-4-16 Matter of Attorneys in Violation of Judiciary Law § 468-a [Flatow] D-5-16 Matter of Attorneys in Violation of Judiciary Law § 468-a [Said] D-6-16 Matter of Attorneys in Violation of Judiciary Law § 468-a [Haffner] D-7-16 Matter of Attorneys in Violation of Judiciary Law § 468-a [Oleary] D-8-16 Matter of Attorneys in Violation of Judiciary Law § 468-a [McAndrew] Session Calendar Session Calendars are updated daily by 5 p.m. Calendar Receipt
For Information on this Calendar, contact: Technical Service Unit | Licensed To: New York, Supreme Court, Appellate Div., Third Judicial Dept.